package operators

import (
	"fmt"
	"os"
	"os/exec"
	"path/filepath"
	"strings"
)

func ReadDocs(pkg string, global bool) error {
	modDir := GlobalPath
	if !global {
		modDir = GetModBaseDir()
	}

	glob, err := filepath.Glob(filepath.Join(modDir, pkg, "*"))
	if err != nil {
		return err
	}

	pager := os.Getenv("SLP_READER")
	if pager == "" {
		pager = os.Getenv("PAGER")
		if pager == "" {
			pager = "less"
		}
	}

	for _, p := range glob {
		base := filepath.Base(p)
		if strings.HasPrefix(strings.ToLower(base), "readme") {
			cmd := exec.Command(pager, p)
			cmd.Stdin = os.Stdin
			cmd.Stdout = os.Stdout
			cmd.Stderr = os.Stderr
			err := cmd.Run()
			if err != nil {
				return err
			}
			return nil
		}
	}

	return fmt.Errorf("Package %q does not have a README file", pkg)
}
