package operators

import (
	"fmt"
	"sort"
)

type pkgs []genOpts

func (p pkgs) Len() int {
	return len(p)
}

func (p pkgs) Swap(i, j int) {
	p[i], p[j] = p[j], p[i]
}

func (p pkgs) Less(i, j int) bool {
	return p[i].Title < p[j].Title
}

// List lists all available packages
// from packages.json
func List() error {
	err := downloadTheDirectory()
	if err != nil {
		return err
	}

	packages, err := getPackages()
	if err != nil {
		return err
	}

	sorted := sortPackages(packages)
	fmt.Printf("Listing %d packages...\n\n", len(sorted))

	for _, p := range sorted {
		fmt.Println(packageString(p))
	}

	return nil
}

func packageString(pkg genOpts) string {
	desc := pkg.Description
	if len([]rune(desc)) > 60 {
		desc = desc[:57] + "..."
	}
	return fmt.Sprintf("\033[1;32m%s\033[0m \033[2m/\033[0m %s\n\tCurrent version: %s\n", pkg.Title, desc, pkg.Version)
}

func longestRepo(pkgs map[string]genOpts) int {
	longest := 0

	for _, val := range pkgs {
		l := len(val.Repository)

		if l > longest {
			longest = l
		}
	}

	return longest
}

func sortPackages(packages map[string]genOpts) pkgs {
	pks := make(pkgs, 0)

	for _, structure := range packages {
		pks = append(pks, structure)
	}

	sort.Sort(pks)
	return pks
}
