package operators

import (
	"fmt"
	"io/ioutil"
	"os"
	"os/exec"
	"path/filepath"
	"strings"
)

const (
	requiredFileCount int = 2
)

func LocalInstall(path string, global bool) error {
	modDir := GlobalPath
	if !global {
		modDir = GetModBaseDir()
	}

	files, err := ioutil.ReadDir(ExpandedAbsFilepath(path))
	if err != nil {
		return fmt.Errorf("  \033[2m└\033[0m \033[91mError:\033[0m %q does not exist or is not accessible", path)
	}

	filesFound := 0
	for _, file := range files {
		switch strings.ToLower(file.Name()) {
		case "module.json":
			filesFound++
		case "main.slo":
			filesFound++
		}
	}

	if filesFound < requiredFileCount {
		return fmt.Errorf("  \033[2m└\033[0m \033[91mError:\033[0m %q does not contain the required files for a module", path)
	}

	pkg := filepath.Base(path)
	if pkg == "/" || pkg == "" || pkg[0] == '.' {
		return fmt.Errorf("  \033[2m└\033[0m \033[91mError:\033[0m %q is not a valid package name", pkg)
	}

	_, err = os.Stat(filepath.Join(modDir, pkg))
	if err == nil {
		return fmt.Errorf("  \033[2m└\033[0m \033[91mError:\033[0m package %q is already installed", pkg)
	}

	cmd := exec.Command("cp", "-r", ExpandedAbsFilepath(path), modDir)
	err = cmd.Run()
	if err != nil {
		return fmt.Errorf("  \033[2m└\033[0m \033[91mError:\033[0m could not install to the module folder")
	}

	return err
}
