package operators

import (
	"encoding/json"
	"fmt"
	"io/ioutil"
	"os"
	"path/filepath"
)

// TODO make this take an optional commit hash
// and/or branch name. Instead of reinstalling,
// is pulling better? It leaves open a repo url
// change as an issue...

// Update removes then installs a
// package, to ensure it is up to date
func Update(pkg string, global bool) error {
	// Get remote data
	err := checkRegistry()
	if err != nil {
		return fmt.Errorf("  \033[2m└\033[0m \033[91mError:\033[0m could not retrieve remote package registry")
	}
	packages, err := getPackages()
	if err != nil {
		return fmt.Errorf("  \033[2m└\033[0m \033[91mError:\033[0m could not read from local copy of 'packages.json' registry")
	}

	// Check current tag
	modDir := GlobalPath
	if !global {
		modDir = GetModBaseDir()
	}
	path := filepath.Join(modDir, pkg)
	if _, err := os.Stat(path); err != nil {
		return fmt.Errorf("  \033[2m└\033[0m \033[91mError:\033[0m package %q is not currently installed", pkg)
	}

	remotePkg, ok := packages[pkg]
	if !ok {
		return fmt.Errorf("  \033[2m└\033[0m \033[91mError:\033[0m package %q not found in package list", pkg)
	}

	path = filepath.Join(path, "module.json")
	if _, err := os.Stat(path); err == nil {
		bytes, err := ioutil.ReadFile(path)
		if err != nil {
			return fmt.Errorf("  \033[2m└\033[0m \033[91mError:\033[0m could not read 'module.json' for %s", pkg)
		}
		var info genOpts
		err = json.Unmarshal(bytes, &info)
		if err != nil {
			return fmt.Errorf("  \033[2m└\033[0m \033[91mError:\033[0m corrupt json formatting in 'module.json' for %s", pkg)
		}

		if info.Version == remotePkg.Version && info.Tag == remotePkg.Tag {
			return fmt.Errorf("  \033[2m└\033[0m \033[32mdone\033[0m A newer version of %q is not available", pkg)
		}
	}

	// Remove and install
	err = Remove(pkg, global)
	if err != nil {
		return err
	}

	err = Install(pkg, global)
	if err != nil {
		return err
	}

	return nil
}
